@@ -4,11 +4,9 @@ import (
 	"fmt"
 	"os"
 	"strings"
-	"time"
 
 	"git.sr.ht/~sircmpwn/aerc/commands"
 	"git.sr.ht/~sircmpwn/aerc/widgets"
-	"github.com/gdamore/tcell"
 	"github.com/mitchellh/go-homedir"
 )
 
@@ -52,8 +50,7 @@ func (Attach) Execute(aerc *widgets.Aerc, args []string) error {
 	composer, _ := aerc.SelectedTab().(*widgets.Composer)
 	composer.AddAttachment(path)
 
-	aerc.PushStatus(fmt.Sprintf("Attached %s", pathinfo.Name()), 10*time.Second).
-		Color(tcell.ColorDefault, tcell.ColorGreen)
+	aerc.PushSuccess(fmt.Sprintf("Attached %s", pathinfo.Name()))
 
 	return nil
 }
